@@ -4,16 +4,12 @@ package Respite::Server;
 
 use strict;
 use warnings;
-use JSON ();
+our @ISA;
+use base 'Respite::Common'; # Default _configs
 use Digest::MD5 qw(md5_hex);
 use Throw qw(throw);
 use Time::HiRes qw(sleep);
 
-our $config;
-
-my $JSON;
-sub json { $JSON ||= JSON->new->utf8->allow_unknown->allow_nonref->allow_blessed->convert_blessed->canonical }
-
 sub server_name {      $_[0]->{'server_name'}      ||= ($0 =~ m|/(\w+)$|x) ? $1 : throw 'Missing server_name' }
 sub revision {         $_[0]->{'revision'}         ||= eval { $_[0]->dispatch_class->_revision } || '-' }
 sub max_request_size { $_[0]->{'max_request_size'} || 2_000_000 }
@@ -29,7 +25,7 @@ sub new {
     return $self if $self->{'non_daemon'} || ($ENV{'MOD_PERL'} && ! $self->{'force_daemon'});
     require Net::Server;
     require Net::Server::HTTP;
-    import base qw(Net::Server::HTTP);
+    unshift @ISA, qw(Net::Server::HTTP) if !$self->isa(qw(Net::Server::HTTP));;
     throw 'We need a more recent Net::Server revision', {v => $Net::Server::VERSION} if $Net::Server::VERSION < 2.007;
     $self->json; # vivify before fork
     my $server = $class->SUPER::new(%$self, %{ $self->server_args });
@@ -41,8 +37,6 @@ sub new {
 
 sub new_args {}
 
-sub _configs { $config || (eval { require config } or $config::config{'failed_load'} = $@) && ($config = config->load) }
-
 sub config {
     my ($self, $key, $def, $name) = @_;
     $name ||= $self->server_name;
@@ -254,6 +248,7 @@ sub content_type { shift->{'content_type'} ||= 'application/json' }
 
 sub send_response {
     my ($self, $str) = @_;
+    $str =~ s/\s*$/\r\n/ if $self->content_type =~ m{^(?:text/|application/json$)};
     my @extra = $self->{'extra_headers'} ? @{ $self->{'extra_headers'} } : ();
     if ($self->{'is_psgi'}) {
         return [200, [(map {$_->[0], $_->[1]} @extra), 'Content-type' => $self->content_type, 'Content-length' => length($str)], [$str]];
@@ -265,7 +260,7 @@ sub send_response {
     } elsif (my $c = $self->{'server'}->{'client'}) { # accelerate output header generation under Net::Server
         my $ri = $self->{'request_info'};
         my $out = "HTTP/1.0 200 OK\015\012";
-         foreach my $row (@{ $self->http_base_headers }, @extra, ['Content-length', length($str)], ['Content-type', $self->content_type]) {
+        foreach my $row (@{ $self->http_base_headers }, @extra, ['Content-length', length($str)], ['Content-type', $self->content_type]) {
             $out .= "$row->[0]: $row->[1]\015\012";
             push @{ $ri->{'response_headers'} }, $row;
         }
@@ -276,10 +271,13 @@ sub send_response {
         $ri->{'response_size'} = length $str;
         $c->print("$out\015\012$str");
     } else {
-        print "Content-Length: ".length($str)."
-Content-Type: ".$self->content_type."
-
-$str";
+        # Otherwise, this is a normal CGI process.
+        # XXX - Do we need to also convert "Status" header for the special NPH format?
+        print "HTTP/1.0 200 OK\r\n" if ($ENV{SCRIPT_FILENAME} // "") =~ m{/nph-[^/]+($|\s)};
+        for my $h (@extra) {
+            print "$h->[0]: $h->[1]\r\n";
+        }
+        print "Content-Type: ".$self->content_type."\r\nContent-Length: ".length($str)."\r\nContent-Type: ".$self->content_type."\r\n\r\n",$str;
     }
     return 1;
 }
